@@ -68,7 +68,7 @@ clust.stats.plot <- function (x = NULL,
           axis.ticks.y=element_blank()) + coord_polar(theta="y")
   # mito
   mito.percent.plot <- ggplot(DATA,aes(y=mito.percent, x=as.factor(clusters))) +
-    geom_jitter(color = cell.color, size = cell.size, alpha = cell.transparency) +
+    geom_jitter(height = 0,color = cell.color, size = cell.size, alpha = cell.transparency) +
     geom_violin(trim=FALSE, col = "black", alpha = cell.transparency) +
     geom_boxplot(fill = box.color, col = "green", notch = notch, outlier.shape = NA, alpha = cell.transparency) +
     xlab("clusters") + ylab("percent of mito genes per cell") +
@@ -76,7 +76,7 @@ clust.stats.plot <- function (x = NULL,
     theme_bw() + theme(axis.text.x=element_text(angle=90))
   # nGenes
   nGenes.plot <- ggplot(DATA,aes(y=nGenes,x=as.factor(clusters))) +
-    geom_jitter(color = cell.color, size = cell.size, alpha = cell.transparency) +
+    geom_jitter(height = 0,color = cell.color, size = cell.size, alpha = cell.transparency) +
     geom_violin(trim=FALSE, col = "black", alpha = cell.transparency) +
     geom_boxplot(fill = box.color, col = box.line.col, notch = notch, outlier.shape = NA, alpha = cell.transparency) +
     xlab("clusters") + ylab("number of genes per cell") +
@@ -84,7 +84,7 @@ clust.stats.plot <- function (x = NULL,
     theme_bw() + theme(axis.text.x=element_text(angle=90))
   # UMIs
   UMIsplot <- ggplot(DATA,aes(y=UMIs,x=as.factor(clusters))) +
-    geom_jitter(color = cell.color, size = cell.size, alpha = cell.transparency) +
+    geom_jitter(height = 0,color = cell.color, size = cell.size, alpha = cell.transparency) +
     geom_violin(trim=FALSE, col = "black", alpha = cell.transparency) +
     geom_boxplot(fill = box.color, col = box.line.col, notch = notch, outlier.shape = NA, alpha = cell.transparency) +
     xlab("clusters") + ylab("number of UMIs per cell") +
